@@ -20,8 +20,8 @@
 #' @param email (required) String giving the correspondance address for the module.
 #' @param dataType Character vector required for all module types except 'covariate'.
 #' Indicates the types of data that this module works with. Values can be any of
-#' 'presence-only', 'presence/absence', 'abundance' or 'proportion'. For a occurrence
-#' model this should indicate the type of data that is retuned and for other modules
+#' 'presence-only', 'presence/absence', 'presence/background', 'abundance' or 'proportion'. For a occurrence
+#' model this should indicate the type of data that is returned and for other modules
 #' should indicate the type of data they will work with. If the module works with
 #' multiple types they can be supplied in a vector, e.g. c('presence-only',
 #' 'presence/absence') 
@@ -48,8 +48,8 @@ BuildModule <- function(object, type, dir='.', title = '',  description = '',
   if(is.null(dataType)){
     if(type != 'covariate') stop('dataType is needed for all modules except covariate modules')
   } else{
-    if(any(!dataType %in% c('presence-only', 'presence/absence', 'abundance', 'proportion'))){
-      stop("dataType must be one of 'presence-only', 'presence/absence', 'abundance' or 'proportion'")
+    if(any(!dataType %in% c('presence-only', 'presence/absence', 'presence/background', 'abundance', 'proportion'))){
+      stop("dataType must be one of 'presence-only', 'presence/absence', 'presence/background', 'abundance' or 'proportion'")
     }
   }
   
